import React, { Component, Fragment } from 'react'
import PropTypes from 'prop-types'
import {
	Page, Validator, Notification, FormItem, DatePickerItem, TextAreaItem, CheckboxItem, Checkbox,
	InputItem , Input, Bind, SelectItem, Button, Label, Image, Table, BottomBtn
} from '@/components/Common-Library'
import Api from '@/service/api'
import mGetame from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { Row, Col } from 'antd'
import { action, observable, runInAction } from 'mobx'
import Business from '@/views/Public/Business'

const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class GetameScreen extends Page {
	static childContextTypes = {
		trn: PropTypes.string,
	}
	getChildContext() {
		return { trn: 'getame' }
	}


	@observable
	formBlur = false

	constructor(props) {
		super(props)
		this.model = props.model
		this.bind = Bind.bind(this)
	}



	//按钮事件
	

	onAmebut_buttxmsel = () => {
		this.formBlur = true  //已触发表单提交处理
		Validator.validate(this.model, this.model.descriptor, async (errors, values) => {
			if (errors)
				return
			const rtnmsg = await Api.post('getame/amebut_buttxmsel', { data: this.model })
			if (rtnmsg.retcod == SUCCESS) {
				this.model.swiadd_ameblk=rtnmsg.data.swiadd_ameblk

			}
			else {
				Notification.error({ message: '服务端请求失败!' })
			}
			//余下逻辑处理

		})
	}
	
	//交易内实现
	renderPage() {
		const bind = this.bind
		const { i18n } = this.props
		const { bchlevelLst } = this.props.extra
		//const {next,pre} = this.props.steps
		if (this.props.flag == true) {
			return <Spin style={{ width: "100%", justifyContent: "center" }} spinning={this.props.flag} />
		}

		return (
			<div style={{ position: "relative" }}>
				<Business wrappedComponentRef={ref => (this.com = ref)} extra={this.props.extra} model={this.model} />

				{/* 第1行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Reference" trn="getame" />
							</Col>
							<Col span={14}>
								<InputItem disabled={true} InputProps={bind("ownref")} maxLength={16} desp="Reference" path="/gidgrp/rec/ownref" />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Name" trn="getame" />
							</Col>
							<Col span={14}>
								<InputItem disabled={true} InputProps={bind("nam")} maxLength={40} desp="Externally Displayed Name to Identify the Contract" path="/gidgrp/rec/nam" />
							</Col>
						</Row>
					</Col>

				</Row>
				{/* 第2行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Amendment Date" trn="getame" />
							</Col>
							<Col span={14}>
								<DatePickerItem  InputProps={bind("swiadd_amedat")} desp="Date of Amendment" path="/gitamep/swiadd/amedat" />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Amend. No Receiv." trn="getame" />
							</Col>
							<Col span={14}>
								<InputItem  InputProps={bind("swiadd_amenbr")} desp="Number of Amendment" path="/gitamep/swiadd/amenbr" />
							</Col>
						</Row>
					</Col>

				</Row>

				{/* 第3行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Order from" trn="getame" />
							</Col>
							<Col span={14}>
								<DatePickerItem disabled={true} InputProps={bind("gitamep_orddat")} desp="Order From" path="/gitamep/orddat" />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Actual Adt No" trn="getame" />
							</Col>
							<Col span={14}>
								<InputItem disabled={true} InputProps={bind("gitamep_amenbr")} desp="Number of Amendment" path="/gitamep/amenbr" />
							</Col>
						</Row>
					</Col>

				</Row>
				{/* 第4行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Old Validity" trn="getame" />
							</Col>
							<Col span={14}>
								<DatePickerItem disabled={true} InputProps={bind("expdat1")} desp="Valid until" path="/oldgidgrp/rec/expdat" />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="New Validity" trn="getame" />
							</Col>
							<Col span={14}>
								<DatePickerItem  InputProps={bind("swiadd_newexpdat")} desp="New Expiry Date" path="/gitamep/swiadd/newexpdat" />
							</Col>
						</Row>
					</Col>

				</Row>
				{/* 第5行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Old Guarantee Amt." trn="getame" />
							</Col>
							<Col span={14}>
								<DatePickerItem disabled={true} InputProps={bind("liadat1")} desp="Liability until" path="/oldgidgrp/rec/liadat" />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="核销日期" trn="getame" />
							</Col>
							<Col span={14}>
								<DatePickerItem disabled={true} InputProps={bind("vrfdat")} desp="核销日期" path="/gidgrp/rec/vrfdat" />
							</Col>
						</Row>
					</Col>

				</Row>
				{/* 第6行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Old Liability " trn="getame" />
							</Col>
							<Col span={6} >
								<InputItem disabled={true} InputProps={bind("max1_cur")} maxLength={3} desp="Currency" path="/oldgidgrp/cbs/max/cur" />
							</Col>
							<Col span={7} offset={1}>
								<InputItem disabled={true} InputProps={bind("max1_amt")} desp="Balance" path="/oldgidgrp/cbs/max/amt" />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="New Liability" trn="getame" />
							</Col>
							<Col span={14}>
								<DatePickerItem  InputProps={bind("swiadd_newliadat")} desp="New Liability Date" path="/gitamep/swiadd/newliadat" />
							</Col>
						</Row>
					</Col>

				</Row>
				{/* 第7行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Guarantee Amount" trn="getame" />
							</Col>
							<Col span={6} >
								<InputItem  InputProps={bind("swiadd_amecur")} maxLength={3} desp="Currency of amended amount" path="/gitamep/swiadd/amecur" />
							</Col>
							<Col span={7} offset={1}>
								<InputItem  InputProps={bind("swiadd_ameamt")} desp="Amended Amount" path="/gitamep/swiadd/ameamt" />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							
							<Col span={5} offset={2}>
								<Label itext="变更次数" trn="getame" />
							</Col>
							<Col span={14}>
								<InputItem disabled={true} InputProps={bind("gitamep_amenumjmg")} maxLength={2} desp="变更次数" path="/gitamep/amenumjmg" />
							</Col>
						</Row>
					</Col>

				</Row>
				
				{/* 第9行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Amounts Covered" trn="getame" />
							</Col>
							<Col span={6} >
								<InputItem  InputProps={bind("swiadd_newcur")} maxLength={3} desp="Currency of new amount" path="/gitamep/swiadd/newcur" />
							</Col>
							<Col span={7} offset={1}>
								<InputItem  InputProps={bind("swiadd_newamt")} desp="New amount" path="/gitamep/swiadd/newamt" />
							</Col>
						</Row>
						<Row className="row">
							<Col span={5} offset={2}>
								{/* <Label itext="Additional Amount Covered" trn="getame" /> */}
								<Label itext="AAC" trn="getame" />
							</Col>
							<Col span={14}>
								<TextAreaItem style={{height:"71px"}}  InputProps={bind("swiadd_addamtcov")} desp="Additional Amount Covered" path="/gitamep/swiadd/addamtcov" />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Adding amount" trn="getame" />
							</Col>
							<Col span={6}>
								<InputItem disabled={true} InputProps={bind("max2_cur")} maxLength={3} desp="Currency" path="/gidgrp/cbs/max2/cur" />
							</Col>
							<Col span={7} offset={1}>
								<InputItem  InputProps={bind("swiadd_addamt")} desp="Additional Amount" path="/gitamep/swiadd/addamt" />
							</Col>
						</Row>
						<Row className="row" >
							<Col span={5} offset={2}>
								<Label itext="Unlimited" trn="getame" />
							</Col>
							<Col span={14} >
								<CheckboxItem InputProps={bind("swiadd_newexpflg")} desp="Unlimited Validity" path="/gitamep/swiadd/newexpflg" />
							</Col>

						</Row>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Add. Amount" trn="getame" />
							</Col>
							<Col span={14} >
								<CheckboxItem InputProps={bind("aammod_addamtflg")} desp="Add. Amount" path="/gitp/aamp/aammod/addamtflg" />
							</Col>
						</Row>

					</Col>

				</Row>
				{/* 第10行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Amendment :77C:" trn="getame" />
							</Col>
							<Col span={14}>
								<TextAreaItem disabled={true}  InputProps={bind("gitamep_ametxt")} desp="Amendment :77C:" path="/gitamep/ametxt" />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								{/* <Label itext="Request of Amendment send to" /> */}
								<Label itext="RoAst" />
							</Col>
							<Col span={11}>
								<SelectItem disabled={true} InputProps={bind("gitamep_ramrol")} desp="Request of Amendment send to" path="/gitamep/ramrol" />
							</Col>
						</Row>
					</Col>

				</Row>
				{/* 第11行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							
							<Col span={5} offset={2}>
								<Label itext="Text for Amendments" trn="getame" />
							</Col>
							<Col span={11}>
								<TextAreaItem style={{ height: "71px" }}  InputProps={bind("swiadd_ameblk")} desp="Text for Amendments" path="/gitamep/swiadd/ameblk" />
							</Col>
							<Col span={2} offset={1}>
								<Button type="primary" icon="search" onClick={this.onAmebut_buttxmsel} desp="..." path="/gitamep/amebut/buttxmsel">
									<Label itext="..." />
								</Button>
							</Col>
							
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								{/* <Label itext="Create Amendment Message" trn="getame" /> */}
								<Label itext="CAM" trn="getame" />
							</Col>
							<Col span={14} >
								<CheckboxItem InputProps={bind("gitamep_cre767flg")} desp="Create Amendment Message" path="/gitamep/cre767flg" />
							</Col>
						</Row>
						<Row className="row">
							<Col span={5} offset={2}>
								{/* <Label itext="choose full text" trn="getame" /> */}
								<Label itext="cft" trn="getame" />
							</Col>
							<Col span={14} >
								<CheckboxItem InputProps={bind("gitamep_prtflg")} desp="choose full text" path="/gitamep/prtflg" />
							</Col>
						</Row>
					</Col>
				</Row>
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								{/* <Label itext="Close picked up claim now" trn="getame" /> */}
								<Label itext="Cpucn" trn="getame" />
							</Col>
							<Col span={14}>
								<CheckboxItem InputProps={bind("gitamep_clsclmflg")} desp="Close picked up claim now" path="/gitamep/clsclmflg" />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								{/* <Label itext="agreement of bene. required" trn="getame" /> */}
								<Label itext="aobr" trn="getame" />
							</Col>
							<Col span={14}>
								<CheckboxItem InputProps={bind("gitamep_abrflg")} desp="agreement of bene. required" path="/gitamep/abrflg" />
							</Col>
						</Row>
					</Col>
				</Row>

				{/* <Label itext="Amended" trn="getame" /> */}
				{/* <Label itext="Amendments" trn="getame" /> */}
				{/* 底部按钮 */}
				<BottomBtn _this={this} />
				
			</div>
		)
	}
}
