import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table,BottomBtn} from '@/components/Common-Library'
import Api from '@/service/api'
import mGitcrj from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'
import {Row ,Col} from 'antd'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class GitcrjScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'gitcrj'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mGitcrj()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('gitcrj/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }

    glemod_glelstHeader=[
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"dbtcdt",
    		key:"dbtcdt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dbtcdt,r2.dbtcdt),
    	},
    	{
    		title:<Label itext="账号" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="起息日" />, 
    		dataIndex:"valdat",
    		key:"valdat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.valdat,r2.valdat),
    	},
    	{
    		title:<Label itext="科目号" />, 
    		dataIndex:"trmtyp",
    		key:"trmtyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.trmtyp,r2.trmtyp),
    	},
    	{
    		title:<Label itext="PN序号" />, 
    		dataIndex:"prn",
    		key:"prn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.prn,r2.prn),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rat",
    		key:"rat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rat,r2.rat),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fctsgn",
    		key:"fctsgn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fctsgn,r2.fctsgn),
    	},
    ]
    glgmod_glslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"debcdtflg",
    		key:"debcdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.debcdtflg,r2.debcdtflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.debcdtflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="结算方式" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp2.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="账户" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="原币种" />, 
    		dataIndex:"acccur",
    		key:"acccur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.acccur,r2.acccur),
    	},
    	{
    		title:<Label itext="原金额" />, 
    		dataIndex:"accamt",
    		key:"accamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.accamt,r2.accamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"actflg",
    		key:"actflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.actflg,r2.actflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fmtamt",
    		key:"fmtamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fmtamt,r2.fmtamt),
    	},
    ]
    liaccv_liaccvgHeader=[
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="原始金额" />, 
    		dataIndex:"oldamt",
    		key:"oldamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.oldamt,r2.oldamt),
    	},
    	{
    		title:<Label itext="变动金额" />, 
    		dataIndex:"chgamt",
    		key:"chgamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.chgamt,r2.chgamt),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="结算账号" />, 
    		dataIndex:"cusact",
    		key:"cusact",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cusact,r2.cusact),
    	},
    	{
    		title:<Label itext="保证金账号" />, 
    		dataIndex:"ccvact",
    		key:"ccvact",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ccvact,r2.ccvact),
    	},
    	{
    		title:<Label itext="记账" />, 
    		dataIndex:"gleflg",
    		key:"gleflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.gleflg,r2.gleflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.onsel.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    ]
    docmod_doclstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"role",
    		key:"role",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.role,r2.role),
    	},
    	{
    		title:<Label itext="码值" />, 
    		dataIndex:"id",
    		key:"id",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.id,r2.id),
    	},
    	{
    		title:<Label itext="凭证名称" />, 
    		dataIndex:"docnam",
    		key:"docnam",
    		width:200,
    		sorter: (r1,r2)=>ColSorter(r1.docnam,r2.docnam),
    	},
    	{
    		title:<Label itext="凭证类型" />, 
    		dataIndex:"cortyp",
    		key:"cortyp",
    		width:150,
    		sorter: (r1,r2)=>ColSorter(r1.cortyp,r2.cortyp),
    	},
    	{
    		title:<Label itext="出具/发送" />, 
    		dataIndex:"mdtflg",
    		key:"mdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.mdtflg,r2.mdtflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"ptainr",
    		key:"ptainr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ptainr,r2.ptainr),
    	},
    ]
    fegmod_feslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="费用代码" />, 
    		dataIndex:"feecod",
    		key:"feecod",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feecod,r2.feecod),
    	},
    	{
    		title:<Label itext="费用名称" />, 
    		dataIndex:"feetxt",
    		key:"feetxt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feetxt,r2.feetxt),
    	},
    	{
    		title:<Label itext="收费币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="应收金额" />, 
    		dataIndex:"basamt",
    		key:"basamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.basamt,r2.basamt),
    	},
    	{
    		title:<Label itext="实收金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="现收/缓收" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="内扣/外收" />, 
    		dataIndex:"payflg",
    		key:"payflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.payflg,r2.payflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.payflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfcur",
    		key:"xrfcur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfcur,r2.xrfcur),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfamt",
    		key:"xrfamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfamt,r2.xrfamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"feeacc",
    		key:"feeacc",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feeacc,r2.feeacc),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fepinr",
    		key:"fepinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fepinr,r2.fepinr),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rolptyinr",
    		key:"rolptyinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rolptyinr,r2.rolptyinr),
    	},
    ]
    liaall_liaallgHeader=[
    	{
    		title:<Label itext="业务种类" />, 
    		dataIndex:"bussec",
    		key:"bussec",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.bussec,r2.bussec),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.bussec.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="表外类型" />, 
    		dataIndex:"liatyp",
    		key:"liatyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.liatyp,r2.liatyp),
    	},
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="原金额" />, 
    		dataIndex:"oldamt",
    		key:"oldamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.oldamt,r2.oldamt),
    	},
    	{
    		title:<Label itext="变动金额" />, 
    		dataIndex:"chgamt",
    		key:"chgamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.chgamt,r2.chgamt),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="表外账号" />, 
    		dataIndex:"acc",
    		key:"acc",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.acc,r2.acc),
    	},
    ]


    //按钮事件
    onChk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/chk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_ast= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/setmod_ast',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSav= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/sav',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_recal= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/setmod_recal',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onOthp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/othp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLiaccv_recalccv= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/liaccv_recalccv',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPed= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/ped',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts2_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/pts2_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGetref= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/getref',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts3_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/pts3_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPrbp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/prbp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onExi= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/exi',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onLiaall_astlia= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/liaall_astlia',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGlemod_rebook= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/glemod_rebook',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_butshw= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/trndoc_butshw',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_feedet= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/setmod_feedet',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_reldoc= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitcrj/trndoc_reldoc',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div style={{ position: 'relative' }}>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Guarantee" trn="gitcrj" />    
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("ownref1")}  maxLength={16}  desp="Reference" path="/gidgrp/rec/ownref" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Open Amount" trn="gitcrj" />  
                            </Col>
                            <Col span={6}>
                                <InputItem InputProps={bind("opn11_cur")}  maxLength={3}  desp="Currency" path="/gidgrp/cbs/opn1/cur" />
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("opn11_amt")}   desp="Balance" path="/gidgrp/cbs/opn1/amt" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                            	<Label value={this.model.gctp_expfldlab}   desp="Label for Field Validity" path="/gctp/expfldlab" />
                            	<Label value={this.model.gctp_explab}   desp="Label unlimited Validity" path="/gctp/explab" />
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("expdat")}  desp="Valid until" path="/gidgrp/rec/expdat" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Name" trn="gitcrj" /> 
                            </Col>
                            <Col span={11}>
                                <InputItem InputProps={bind("nam")}  maxLength={40}  desp="Externally Displayed Name to Identify the Contract" path="/gcdgrp/rec/nam" />
                            </Col>
                            <Col span={2} offset={1}>
                                <Button  type="primary"  onClick={this.onGetref} desp="Get Ref." path="/mtabut/getref">
                                    <Label   itext="获取"/>
                                </Button>
                            </Col>
                        </Row>
                    </Col>
                </Row>

                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Claim Number" trn="gitcrj" /> 
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Reference" path="/gcdgrp/rec/ownref" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Ref." trn="gitcrj" /> 
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("pts_ref")}  maxLength={16}  desp="参考号" path="/gcdgrp/apl/pts/ref" />
                            </Col>
                        </Row>
                    </Col>
                </Row>            	
                            	<Label itext="Applicant" trn="gitcrj" />	
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Amount Claimed" trn="gitcrj" />   
                            </Col>
                            <Col span={6}>
                                <SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/gcdgrp/cbs/max/cur"/>
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("max_amt")}   desp="Balance" path="/gcdgrp/cbs/max/amt" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={1} offset={2}>
                                <CheckboxItem InputProps={bind("gctp_adaflg")}  desp="Add. Amount" path="/gctp/adaflg" />
                            </Col>
                            <Col span={17} offset={1}>
                                <InputItem InputProps={bind("pts_nam")}  maxLength={100}  desp="客户英文名称" path="/gcdgrp/apl/pts/nam" />
                            </Col>
                        </Row>
                    </Col>
                </Row> 
                            	
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Open Amount" trn="gitcrj" />  
                            </Col>
                            <Col span={6}>
                                <SelectItem InputProps={bind("opn1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/gcdgrp/cbs/opn1/cur"/>
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("opn1_amt")}   desp="Balance" path="/gcdgrp/cbs/opn1/amt" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label value={this.model.gctp_aplmullab}   desp="Label, that is set, if there are multiple applicants" path="/gctp/aplmullab" />
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("gartyp")} code={CodeTable.typgar}  desp="Type of Undertaking" path="/gidgrp/rec/gartyp"/>
                            </Col>
                        </Row>
                    </Col>
                </Row> 
                            	<Label itext="Type of Undertaking" trn="gitcrj" />	
                            	<Label itext="Beneficiary" trn="gitcrj" />	
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Ref." trn="gitcrj" /> 
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("pts1_ref")}  maxLength={16}  desp="参考号" path="/gcdgrp/ben/pts/ref" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <DatePickerItem InputProps={bind("liadat")}  desp="Liability until" path="/gidgrp/rec/liadat" />
                            </Col>
                            <Col span={13} offset={1}>
                                <InputItem InputProps={bind("pts1_nam")}  maxLength={100}  desp="客户英文名称" path="/gcdgrp/ben/pts/nam" />
                            </Col>
                        </Row>
                    </Col>
                </Row>                            	
                            	<Label value={this.model.gctp_liafldlab}   desp="Label for Field Liability" path="/gctp/liafldlab" />
                            	<Label value={this.model.gctp_lialab}   desp="Label unlimited Liability" path="/gctp/lialab" />
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Date of Claim" trn="gitcrj" />    
                            </Col>
                            <Col span={13}>
                                <DatePickerItem InputProps={bind("clmdat")}  desp="Date of Claim" path="/gcdgrp/rec/clmdat" />
                            </Col>
                            <Col span={1}>
                                <CheckboxItem InputProps={bind("mtabut_clsflg")}  desp="Close Flag" path="/mtabut/clsflg" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Presented by" trn="gitcrj" /> 
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("docprbrol")}   desp="Presented by" path="/gcdgrp/rec/docprbrol"/>
                            </Col>
                        </Row>
                    </Col>
                </Row>            	
           	
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Message Date" trn="gitcrj" /> 
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("msgdat")}  desp="Rejection Message Date" path="/gcdgrp/rec/msgdat" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Reference" trn="gitcrj" />    
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("pts3_ref")}  maxLength={16}  desp="参考号" path="/gcdgrp/prb/pts/ref" />
                            </Col>
                        </Row>
                    </Col>
                </Row>     
                            	
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Reason of Rejection" trn="gitcrj" />  
                            </Col>
                            <Col span={14}>
                                <TextAreaItem InputProps={bind("strinf")} desp="Narrative" path="/strinf"/>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Payer" trn="gitcrj" />    
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("payrol")}   desp="Payer" path="/gcdgrp/rec/payrol"/>
                            </Col>
                        </Row>
                    </Col>
                </Row>   
                            	
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={15} offset={2}>
                                <InputItem InputProps={bind("pts3_extkey")}  maxLength={16}  desp="客户编号" path="/gcdgrp/prb/pts/extkey" />
                            </Col>
                            <Col span={3} offset={1}>
                                <Button  type="primary" icon="search" onClick={this.onPrbp_sel} desp="查询" path="/gctp/prbp/sel">
                                    <Label   itext="查询"/>
                                </Button>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={15} offset={2}>
                                <InputItem InputProps={bind("pts2_extkey")}  maxLength={16}  desp="客户编号" path="/gcdgrp/oth/pts/extkey" />
                            </Col>
                            <Col span={3} offset={1}>
                                <Button  type="primary" icon="search" onClick={this.onOthp_sel} desp="查询" path="/gctp/othp/sel">
                                    <Label   itext="查询"/>
                                </Button>
                            </Col>
                        </Row>
                    </Col>
                </Row>   
                <Row>
                    <Col span={12}>
                        <Row className="row">
                           <Col span={19} offset={2}>
                                <TextAreaItem InputProps={bind("pts3_adrblk")} desp="SWIFT地址" path="/gcdgrp/prb/pts/adrblk"/>
                            </Col> 
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={19} offset={2}>
                                <TextAreaItem InputProps={bind("pts2_adrblk")} desp="SWIFT地址" path="/gcdgrp/oth/pts/adrblk"/>
                            </Col>
                        </Row>
                    </Col>
                </Row> 
                 {/* 底部按钮 */}
                <BottomBtn _this={this} />        
		</div>
		)
	}
}
