import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table,BottomBtn} from '@/components/Common-Library'
import Api from '@/service/api'
import mGitfre from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'
import {Row ,Col} from 'antd'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class GitfreScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'gitfre'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mGitfre()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('gitfre/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }

    glemod_glelstHeader=[
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"dbtcdt",
    		key:"dbtcdt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dbtcdt,r2.dbtcdt),
    	},
    	{
    		title:<Label itext="账号" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    	},
    	{
    		title:<Label itext="金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="起息日" />, 
    		dataIndex:"valdat",
    		key:"valdat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.valdat,r2.valdat),
    	},
    	{
    		title:<Label itext="科目号" />, 
    		dataIndex:"trmtyp",
    		key:"trmtyp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.trmtyp,r2.trmtyp),
    	},
    	{
    		title:<Label itext="PN序号" />, 
    		dataIndex:"prn",
    		key:"prn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.prn,r2.prn),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rat",
    		key:"rat",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rat,r2.rat),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fctsgn",
    		key:"fctsgn",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fctsgn,r2.fctsgn),
    	},
    ]
    docmod_doclstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"role",
    		key:"role",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.role,r2.role),
    	},
    	{
    		title:<Label itext="码值" />, 
    		dataIndex:"id",
    		key:"id",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.id,r2.id),
    	},
    	{
    		title:<Label itext="凭证名称" />, 
    		dataIndex:"docnam",
    		key:"docnam",
    		width:200,
    		sorter: (r1,r2)=>ColSorter(r1.docnam,r2.docnam),
    	},
    	{
    		title:<Label itext="凭证类型" />, 
    		dataIndex:"cortyp",
    		key:"cortyp",
    		width:150,
    		sorter: (r1,r2)=>ColSorter(r1.cortyp,r2.cortyp),
    	},
    	{
    		title:<Label itext="出具/发送" />, 
    		dataIndex:"mdtflg",
    		key:"mdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.mdtflg,r2.mdtflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"ptainr",
    		key:"ptainr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.ptainr,r2.ptainr),
    	},
    ]
    fegmod_feslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="费用代码" />, 
    		dataIndex:"feecod",
    		key:"feecod",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feecod,r2.feecod),
    	},
    	{
    		title:<Label itext="费用名称" />, 
    		dataIndex:"feetxt",
    		key:"feetxt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feetxt,r2.feetxt),
    	},
    	{
    		title:<Label itext="收费币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="应收金额" />, 
    		dataIndex:"basamt",
    		key:"basamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.basamt,r2.basamt),
    	},
    	{
    		title:<Label itext="实收金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="现收/缓收" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="内扣/外收" />, 
    		dataIndex:"payflg",
    		key:"payflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.payflg,r2.payflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.payflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfcur",
    		key:"xrfcur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfcur,r2.xrfcur),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"xrfamt",
    		key:"xrfamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.xrfamt,r2.xrfamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"feeacc",
    		key:"feeacc",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.feeacc,r2.feeacc),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fepinr",
    		key:"fepinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fepinr,r2.fepinr),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"rolptyinr",
    		key:"rolptyinr",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rolptyinr,r2.rolptyinr),
    	},
    ]
    glgmod_glslstHeader=[
    	{
    		title:<Label itext="角色" />, 
    		dataIndex:"rol",
    		key:"rol",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.rol,r2.rol),
    	},
    	{
    		title:<Label itext="借/贷" />, 
    		dataIndex:"debcdtflg",
    		key:"debcdtflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.debcdtflg,r2.debcdtflg),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.debcdtflg.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算币种" />, 
    		dataIndex:"cur",
    		key:"cur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.cur,r2.cur),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.curtxt.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="结算金额" />, 
    		dataIndex:"amt",
    		key:"amt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.amt,r2.amt),
    	},
    	{
    		title:<Label itext="结算方式" />, 
    		dataIndex:"dsp",
    		key:"dsp",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.dsp,r2.dsp),
    		render:(val, row, index)=>{
    			let text = val
    			let em = CodeTable.dsp2.find(item=>item.value==val)
    			if(em)
    				text= em.label
    			return text
    		}
    	},
    	{
    		title:<Label itext="账户" />, 
    		dataIndex:"act",
    		key:"act",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.act,r2.act),
    	},
    	{
    		title:<Label itext="原币种" />, 
    		dataIndex:"acccur",
    		key:"acccur",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.acccur,r2.acccur),
    	},
    	{
    		title:<Label itext="原金额" />, 
    		dataIndex:"accamt",
    		key:"accamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.accamt,r2.accamt),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"actflg",
    		key:"actflg",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.actflg,r2.actflg),
    	},
    	{
    		title:<Label itext="" />, 
    		dataIndex:"fmtamt",
    		key:"fmtamt",
    		width:100,
    		sorter: (r1,r2)=>ColSorter(r1.fmtamt,r2.fmtamt),
    	},
    ]


    //按钮事件
    onFmop_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitfre/fmop_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onChk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitfre/chk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_ast= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitfre/setmod_ast',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSav= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitfre/sav',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onFmcp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitfre/fmcp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_recal= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitfre/setmod_recal',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPed= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitfre/ped',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTxtfre_buttxmsel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitfre/txtfre_buttxmsel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitfre/pts_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onPts1_adrblk= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitfre/pts1_adrblk',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onExi= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitfre/exi',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onGlemod_rebook= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitfre/glemod_rebook',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_butshw= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitfre/trndoc_butshw',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onSetmod_feedet= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitfre/setmod_feedet',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    onTrndoc_reldoc= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('gitfre/trndoc_reldoc',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div style={{ position: 'relative' }}>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Reference" trn="gitfre" />    
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Reference" path="/gidgrp/rec/ownref" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Name" trn="gitfre" /> 
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("nam")}  maxLength={40}  desp="Externally Displayed Name to Identify the Contract" path="/gidgrp/rec/nam" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                            	<Label itext="Applicant" trn="gitfre" />	
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Guarantee Amount" trn="gitfre" /> 
                            </Col>
                            <Col span={6}>
                                <InputItem InputProps={bind("max_cur")}  maxLength={3}  desp="Currency" path="/gidgrp/cbs/max/cur" />
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("max_amt")}   desp="Balance" path="/gidgrp/cbs/max/amt" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label value={this.model.gitp0_aplmullab}   desp="Label, that is set, if there are multiple applicants" path="/gitp0/aplmullab" />
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("pts3_nam")}  maxLength={100}  desp="客户英文名称" path="/gidgrp/apl/pts/nam" />
                            </Col>
                        </Row>
                    </Col>
                </Row>           	

                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Open Amount" trn="gitfre" />  
                            </Col>
                            <Col span={6}>
                                <InputItem InputProps={bind("opn1_cur")}  maxLength={3}  desp="Currency" path="/gidgrp/cbs/opn1/cur" />
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("opn1_amt")}   desp="Balance" path="/gidgrp/cbs/opn1/amt" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Handling Type" trn="gitfre" />    
                            </Col>
                            <Col span={6}>
                                <SelectItem InputProps={bind("hndtyp")} code={CodeTable.hndtyp}  desp="Handling Type" path="/gidgrp/rec/hndtyp"/>
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("pts4_nam")}  maxLength={100}  desp="客户英文名称" path="/gidgrp/ben/pts/nam" />
                            </Col>
                        </Row>
                    </Col>
                </Row> 
                            	<Label itext="Beneficiary" trn="gitfre" />	
                            	<Label itext="Adv\Rcv Bank" trn="gitfre" />	
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Type of Undertaking" trn="gitfre" />  
                            </Col>
                            <Col span={6}>
                                <SelectItem InputProps={bind("gartyp")} code={CodeTable.typgar}  desp="Type of Undertaking" path="/gidgrp/rec/gartyp"/>
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("pts2_nam")}  maxLength={100}  desp="客户英文名称" path="/gidgrp/adv/pts/nam" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label value={this.model.gitp0_expfldlab}   desp="Label for Field Validity" path="/gitp0/expfldlab" />
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("expdat")}  desp="Valid until" path="/gidgrp/rec/expdat" />
                            </Col>
                        </Row>
                    </Col>
                </Row> 
                
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Issuing Bank" trn="gitfre" /> 
                            </Col>
                            <Col span={6}>
                                <DatePickerItem InputProps={bind("liadat")}  desp="Liability until" path="/gidgrp/rec/liadat" />
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("pts5_nam")}  maxLength={100}  desp="客户英文名称" path="/gidgrp/iss/pts/nam" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="收报行" trn="gitfre" />  
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("fremsg_msgrol")} code={CodeTable.rolall}  desp="Role Message" path="/fremsg/msgrol"/>
                            </Col>
                        </Row>
                    </Col>
                </Row> 	
                            	<Label value={this.model.gitp0_liafldlab}   desp="Label for Field Lability" path="/gitp0/liafldlab" />

                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Issuing Bank" trn="gitfre" /> 
                            </Col>
                            <Col span={6}>
                                <DatePickerItem InputProps={bind("liadat")}  desp="Liability until" path="/gidgrp/rec/liadat" />
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("pts5_nam")}  maxLength={100}  desp="客户英文名称" path="/gidgrp/iss/pts/nam" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="收报行" trn="gitfre" />  
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("fremsg_msgrol")} code={CodeTable.rolall}  desp="Role Message" path="/fremsg/msgrol"/>
                            </Col>
                        </Row>
                    </Col>
                </Row> 

                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="发报类型" trn="gitfre" /> 
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("fremsg_sndmt")} code={CodeTable.sndmt}  desp="message to be created" path="/fremsg/sndmt"/>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="报文类型" trn="gitfre" /> 
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("fremsg_fulmt")} code={CodeTable.fulmt}  desp="MT to Send" path="/fremsg/fulmt"/>
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={15} offset={2}>
                                <InputItem InputProps={bind("pts1_extkey")}  maxLength={16}  desp="客户编号" path="/fremsg/fmo/pts/extkey" />
                            </Col>
                            <Col span={3} offset={1}>
                                <Button  type="primary" icon="search" onClick={this.onFmop_sel} desp="查询" path="/fremsg/fmop/sel">
                                    <Label   itext="查询"/>
                                </Button>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="标题" trn="gitfre" />   
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("fremsg_prttitle")}  maxLength={35}  desp="Document Title" path="/fremsg/prttitle" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                            	
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={19} offset={2}>
                                <TextAreaItem InputProps={bind("pts1_adrblk")} desp="SWIFT地址" path="/fremsg/fmo/pts/adrblk"/>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="相关报文" trn="gitfre" /> 
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("fremsg_relmt")} code={CodeTable.relmt}  desp="related MT" path="/fremsg/relmt"/>
                            </Col>
                        </Row>
                    </Col>
                </Row>
                            	
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label value={this.model.fremsg_reldatlab}   desp="label for date" path="/fremsg/reldatlab" />
                            </Col>
                            <Col span={6}>
                                <DatePickerItem InputProps={bind("fremsg_reldat")}  desp="from" path="/fremsg/reldat" />
                            </Col>
                            <Col span={7} offset={1}>
                                <SelectItem InputProps={bind("fremsg_reldir")} code={CodeTable.reldir}  desp="relevant message sent/received" path="/fremsg/reldir"/>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="副本的收报行" trn="gitfre" />   
                            </Col>
                            <Col span={12}>
                                <SelectItem InputProps={bind("fremsg_ccrol")} code={CodeTable.rolall}  desp="Role Copy" path="/fremsg/ccrol"/>
                            </Col>
                            <Col span={1} offset={1}>
                                <CheckboxItem InputProps={bind("fremsg_flg")}  desp="flg for gitfre" path="/fremsg/flg" />
                            </Col>
                        </Row>
                    </Col>
                </Row>

                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={15} offset={2}>
                                <InputItem InputProps={bind("pts_extkey")}  maxLength={16}  desp="客户编号" path="/fremsg/fmc/pts/extkey" />
                            </Col>
                            <Col span={3} offset={1}>
                                <Button  type="primary" icon="search" onClick={this.onFmcp_sel} desp="查询" path="/fremsg/fmcp/sel">
                                    <Label   itext="查询"/>
                                </Button>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label value={this.model.fremsg_tag20lab}   desp="MT799tag20" path="/fremsg/tag20lab" />
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("fremsg_tag20ref")}  maxLength={16}  desp="tag 20 Ref" path="/fremsg/tag20ref" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
            	<Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={19} offset={2}>
                                <TextAreaItem InputProps={bind("pts_adrblk")} desp="SWIFT地址" path="/fremsg/fmc/pts/adrblk"/>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label value={this.model.fremsg_strinflab}   desp="label for tag 79" path="/fremsg/strinflab" />
                            </Col>
                            <Col span={10}>
                                <TextAreaItem InputProps={bind("fremsg_strinf")} desp="Narrative" path="/fremsg/strinf"/>
                            </Col>
                            <Col span={3} offset={1}>
                                <Button  type="primary" icon="search" onClick={this.onTxtfre_buttxmsel} desp="..." path="/fremsg/txtfre/buttxmsel">
                                    <Label   itext="..."/>
                                </Button>
                            </Col>
                        </Row>
                    </Col>
                </Row>
                {/* 底部按钮 */}
                <BottomBtn _this={this} /> 
		</div>
		)
	}
}
